このページで

zabbix_sender

ZABBIX_SENDER(1)            General Commands Manual           ZABBIX_SENDER(1)

名前
       zabbix_sender - Zabbix senderユーティリティ

書式
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

説明
       zabbix_senderは、監視データをZabbixサーバーまたはプロキシに送信する
       コマンドラインユーティリティです。Zabbixサーバー上に、対応するキーを
       持つZabbixトラッパータイプのアイテムを作成する必要があります。この
       アイテムの「許可されたホスト」フィールドで指定されたホストからの値
       だけが受け付けられることに注意してください。

オプション
       -c, --config config-file
              config-fileを使用します。Zabbix senderはエージェントの設定ファイル
              からサーバーの詳細を読み取ります。デフォルトでは、Zabbix senderは
              設定ファイルを読み取りません。サポートされるパラメータは、
              Hostname、ServerActive、SourceIP、TLSConnect、TLSCAFile、TLSCRLFile、
              TLSServerCertIssuer、TLSServerCertSubject、TLSCertFile、TLSKeyFile、
              TLSPSKIdentity、TLSPSKFileのみです。HostnameItemパラメータで定義
              されたHostnameは取得されません。この場合、ホスト名をコマンドライン
              で指定する必要があります(-sオプションを参照)。エージェントの
              ServerActive設定パラメータで定義されたすべてのアドレスがデータの
              送信に使用されます。バッチデータの送信がいずれかのアドレスで失敗
              した場合、それ以降のバッチはそのアドレスには送信されません。

       -z, --zabbix-server server
              Zabbixサーバーのホスト名またはIPアドレス。ホストがプロキシによって
              監視されている場合は、プロキシのホスト名またはIPアドレスを使用
              する必要があります。--configと併用した場合、エージェント設定
              ファイルで指定されたServerActiveのエントリを上書きします。

       -p, --port port
              サーバー上で実行されているZabbixサーバートラッパーのポート番号を
              指定します。デフォルトは10051です。--configと併用した場合、
              エージェント設定ファイルで指定されたServerActiveのポートエントリ
              を上書きします。

       -I, --source-address IP-address
              送信元IPアドレスを指定します。--configと併用した場合、エージェント
              設定ファイルで指定されたSourceIPパラメータを上書きします。

       -t, --timeout seconds
              タイムアウトを指定します。有効範囲は1~300秒です(デフォルト: 60)。

       -s, --host host
              アイテムが属するホスト名を指定します(ZabbixのWebインターフェース
              に登録されている名前)。ホストのIPアドレスおよびDNS名は使用でき
              ません。--configと併用した場合、エージェント設定ファイルで指定
              されたHostnameパラメータを上書きします。

       -k, --key key
              値を送信するアイテムキーを指定します。

       -o, --value value
              アイテムの値を指定します。

       -i, --input-file input-file
              入力ファイルから値を読み込みます。標準入力から値を読み取るには、
              <input-file>として-を指定します。ファイルの各行には、空白で区切ら
              れた次の項目を含めます: <hostname> <key> <value>。各値はそれぞれ
              独立した行に指定する必要があります。各行には、空白で区切られた
              3つのエントリを含める必要があります: <hostname> <key> <value>。
              ここで、「hostname」はZabbixのWebインターフェースに登録された
              監視対象ホストの名前、「key」は対象アイテムのキー、「value」は
              送信する値です。エージェント設定ファイルまたは--host引数のホスト
              名を使用するには、<hostname>として-を指定します。

              入力ファイルの行の例:

               "Linux DB3" db.connections 43

              値のタイプは、ZabbixのWebインターフェースのアイテム設定で正しく
              設定する必要があります。Zabbix senderは、1つの接続で最大250個の
              値を送信します。入力ファイルの内容はUTF-8エンコーディングでなけ
              ればなりません。入力ファイルのすべての値は、上から下への順番で
              逐次送信されます。エントリは次の規則に従ってフォーマットする必要
              があります。

                     • 引用符付きエントリと引用符なしエントリを使用できます。

                     • 引用文字は二重引用符です。

                     • 空白を含むエントリは引用符で囲む必要があります。

                     • 引用符で囲まれたエントリ内の二重引用符およびバックスラッシュ
                       文字は、バックスラッシュでエスケープする必要があります。

                     • 引用符なしエントリではエスケープはサポートされません。

                     • 引用符で囲まれた文字列では、改行エスケープシーケンス(\n)
                       がサポートされます。

                     • 改行エスケープシーケンスは、エントリの末尾から削除されます。

       -T, --with-timestamps
              このオプションは--input-fileオプションとの併用時のみ使用できます。

              入力ファイルの各行には、空白で区切られた4つのエントリを含める必要
              があります: <hostname> <key> <timestamp> <value>。タイムスタンプは
              Unixタイムスタンプ形式で指定する必要があります。対象アイテムを
              参照するトリガーがある場合、すべてのタイムスタンプは昇順でなければ
              なりません。そうでない場合、イベントの計算が正しく行われません。

              入力ファイルの行の例:

               "Linux DB3" db.connections 1429533600 43

              詳細については、--input-fileオプションを参照してください。

              「データなし」タイプのメンテナンス期間中のホストにタイムスタンプ
              付きの値を送信した場合、その値は破棄されます。ただし、期限切れの
              メンテナンス期間にタイムスタンプ付きの値を送信することは可能で、
              その値は受け付けられます。

       -N, --with-ns
              このオプションは--with-timestampsオプションとの併用時のみ使用
              できます。

              入力ファイルの各行には、空白で区切られた5つのエントリを含める必要
              があります: <hostname> <key> <timestamp> <ns> <value>。

              入力ファイルの行の例:

               "Linux DB3" db.connections 1429533600 7402561 43

              詳細については、--input-fileオプションを参照してください。

       -r, --real-time
              値を受信するとすぐに1つずつ送信します。標準入力から読み取る場合に
              使用できます。

       --tls-connect value
              サーバーまたはプロキシへの接続方法。値:

                   unencrypted
                               暗号化せずに接続します(デフォルト)。

                   psk         TLSと事前共有鍵を使用して接続します。

                   cert        TLSと証明書を使用して接続します。

       --tls-ca-file CA-file
              ピア証明書の検証に使用する、最上位CA証明書を含むファイルの完全な
              パス名。

       --tls-crl-file CRL-file
              失効した証明書を含むファイルの完全なパス名。

       --tls-server-cert-issuer cert-issuer
              許可するサーバー証明書の発行者。

       --tls-server-cert-subject cert-subject
              許可するサーバー証明書のサブジェクト。

       --tls-cert-file cert-file
              証明書または証明書チェーンを含むファイルの完全なパス名。

       --tls-key-file key-file
              秘密鍵を含むファイルの完全なパス名。

       --tls-psk-identity PSK-identity
              PSK-identity文字列。

       --tls-psk-file PSK-file
              事前共有鍵を含むファイルの完全なパス名。

       --tls-cipher13 cipher-string
              TLS 1.3用のOpenSSL 1.1.1以降の暗号文字列。デフォルトの暗号スイート
              選択基準を上書きします。OpenSSLのバージョンが1.1.1未満の場合、
              このオプションは使用できません。

       --tls-cipher cipher-string
              GnuTLSの優先度文字列(TLS 1.2以降)またはOpenSSLの暗号文字列
              (TLS 1.2のみ)。デフォルトの暗号スイート選択基準を上書きします。

       -v, --verbose
              詳細モード。-vvを指定すると、さらに詳細な情報を表示します。

       -h, --help
              このヘルプを表示して終了します。

       -V, --version
              バージョン情報を出力して終了します。

終了ステータス
       値が送信され、すべての値がサーバーによって正常に処理された場合、終了
       ステータスは0です。データが送信されたものの、少なくとも1つの値の処理に
       失敗した場合、終了ステータスは2です。データの送信に失敗した場合、終了
       ステータスは1です。

例
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              監視対象ホストのmysql.queriesアイテムの値として342.45を送信します。
              エージェント設定ファイルで定義された監視対象ホストとZabbixサーバー
              を使用します。

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              エージェント設定ファイルで定義されたZabbixサーバーを使用して、
              Monitored Hostホストのmysql.queriesアイテムの値として342.45を送信
              します。

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              ファイルdata_values.txtの値を、IPアドレス192.168.1.113のZabbix
              サーバーに送信します。ホスト名とキーはファイル内で定義されます。

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              コマンドラインからタイムスタンプ付きの値を、エージェント設定
              ファイルで指定されたZabbixサーバーに送信します。入力データの
              ダッシュは、同じ設定ファイルのホスト名も使用することを示します。

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              コマンドラインから、IPアドレス192.168.1.113、ポート10000のZabbix
              サーバーにアイテムの空の値を送信します。空の値は空の二重引用符で
              示す必要があります。

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              TLSと証明書を使用して、Monitored Hostホストのmysql.queriesアイテム
              の値として342.45をIPアドレス192.168.1.113のサーバーに送信します。

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              TLSと事前共有鍵(PSK)を使用して、Monitored Hostホストのmysql.queries
              アイテムの値として342.45をIPアドレス192.168.1.113のサーバーに送信
              します。

関連項目
       Documentation

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)